(user.graphical_user_interface)=
# Graphical User Interface (GUI)

BEC Widgets is a comprehensive extension for BEC that enables user interaction with the code via a graphical user interface (GUI). For detailed guidance on utilizing the GUI, please visit the [BEC Widgets documentation](https://bec-widgets.readthedocs.io/en/latest/).

Additionally, some GUI elements can be directly accessed through the command line interface if `BEC Widgets` is installed.

## BECFigure

For the time being, please refer to the [API reference](https://bec-widgets.readthedocs.io/en/latest/developer/_autosummary/bec_widgets.cli.client.BECFigure.html#bec_widgets.cli.client.BECFigure). 

A more detailed documentation is coming soon!